// parser.h
// merges different feed formats into a generic feed handler

#ifndef PARSER_H
#define PARSER_H

#include <string>

struct ParseNewsHandler
{
	virtual void setTitle (const std::string &title) = 0;
	virtual void setSummary (const std::string &summary) = 0;
	virtual void setContent (const std::string &content) = 0;
	virtual void setLink (const std::string &link) = 0;
	virtual void setDate (const std::string &date) = 0;
	virtual void setAuthor (const std::string &author) = 0;
	virtual void addCategory (const std::string &category) = 0;
	virtual void setId (const std::string &id) = 0;
};

struct ParseFeedHandler
{
	virtual void setTitle (const std::string &title) = 0;
	virtual void setDescription (const std::string &description) = 0;
	virtual void setLink (const std::string &link) = 0;
	virtual void setAuthor (const std::string &author) = 0;
	virtual ParseNewsHandler *appendNews() = 0;
};

typedef void (*parse_done_callback) (ParseFeedHandler *, const std::string &error);  // runs in another thread
void parse (ParseFeedHandler *handler, const std::string &url,
            const std::string &codeset, parse_done_callback func);

// utilities:

typedef size_t (*write_callback) (char *buffer, size_t size, size_t nitems, void *outstream);
bool download (const std::string &url, write_callback func, void *data);
void download_thread (const char *url, write_callback func, void *data);

std::string download (const std::string &url);

#endif /*PARSER_H*/

